Module: OpenTelemetry

Defined in:
lib/opentelemetry/sampler/xray/utils.rb,
lib/opentelemetry/sampler/xray/version.rb,
lib/opentelemetry/sampler/xray/rule_cache.rb,
lib/opentelemetry/sampler/xray/statistics.rb,
lib/opentelemetry/sampler/xray/rate_limiter.rb,
lib/opentelemetry/sampler/xray/sampling_rule.rb,
lib/opentelemetry/sampler/xray/fallback_sampler.rb,
lib/opentelemetry/sampler/xray/rate_limiting_sampler.rb,
lib/opentelemetry/sampler/xray/sampling_rule_applier.rb,
lib/opentelemetry/sampler/xray/aws_xray_remote_sampler.rb,
lib/opentelemetry/sampler/xray/aws_xray_sampling_client.rb,
lib/opentelemetry/sampler/xray.rb

Overview

OpenTelemetry is an open source observability framework, providing a general-purpose API, SDK, and related tools required for the instrumentation of cloud-native software, frameworks, and libraries.

The OpenTelemetry module provides global accessors for telemetry objects. See the documentation for the opentelemetry-api gem for details.

Defined Under Namespace

Modules: Sampler